diff --git a/.airgeddonrc b/.airgeddonrc
index 0f5dc41..e415a3f 100644
--- a/.airgeddonrc
+++ b/.airgeddonrc
@@ -25,6 +25,9 @@ AIRGEDDON_5GHZ_ENABLED=true
 #Enabled true / Disabled false - Force to use iptables instead of nftables (it has no effect if nftables are not present) - Default value false
 AIRGEDDON_FORCE_IPTABLES=false
 
+#Enabled true / Disabled false - Force to kill Network Manager before launching Evil Twin attacks - Default value true
+AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING=true
+
 #Available values: mdk3, mdk4 - Define which mdk version is going to be used - Default value mdk4
 AIRGEDDON_MDK_VERSION=mdk4
 
diff --git a/.editorconfig b/.editorconfig
new file mode 100644
index 0000000..48d0ea8
--- /dev/null
+++ b/.editorconfig
@@ -0,0 +1,19 @@
+#EditorConfig: http://editorconfig.org
+
+root = true
+
+[*]
+charset = utf-8
+end_of_line = lf
+insert_final_newline = true
+
+[*.{sh,db,txt}]
+trim_trailing_whitespace = true
+
+[*.{sh,db}]
+indent_style = tab
+indent_size = 4
+
+[Dockerfile]
+indent_style = tab
+indent_size = 4
diff --git a/.gitattributes b/.gitattributes
new file mode 100644
index 0000000..71c89be
--- /dev/null
+++ b/.gitattributes
@@ -0,0 +1,15 @@
+# Auto detect text files and perform LF normalization
+* text=auto
+
+# Text files and source code
+*.txt text
+*.sh text
+*.md text
+*.db text
+
+# Executable binaries/packages
+*.deb binary
+*.xz binary
+
+# Binary image formats
+*.png binary
\ No newline at end of file
diff --git a/.github/FUNDING.yml b/.github/FUNDING.yml
new file mode 100644
index 0000000..5aa405d
--- /dev/null
+++ b/.github/FUNDING.yml
@@ -0,0 +1,3 @@
+# These are supported funding model platforms
+
+custom: ['https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=7ELM486P7XKKG', 'https://www.blockchain.com/btc/address/1NSzwqtBBdo4CrvynPZmd85xfbL7hw3Ptu', 'https://www.blockchain.com/eth/address/0xf88107ba5e10776a37ec089a7ed2bac57638eea7', 'https://www.buymeacoffee.com/v1s1t0r']
diff --git a/.github/ISSUE_TEMPLATE.md b/.github/ISSUE_TEMPLATE.md
new file mode 100644
index 0000000..d366775
--- /dev/null
+++ b/.github/ISSUE_TEMPLATE.md
@@ -0,0 +1,22 @@
+<!--- Please, consider to contact us on Discord or IRC before opening an issue. More info and Discord invitation link here: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Contact -->
+<!--- Answer the questions to provide maximum of info -->
+<!--- Filling this issue template is mandatory. Otherwise the issue can be directly closed -->
+<!--- Write in English only -->
+<!--- If additional info is required and requested by airgeddon's staff, you have 7 days to respond, otherwise the issue will be closed -->
+<!--- Read the Issue Creation Policy on Contributing section before creating the issue -->
+
+#### What is your airgeddon version?
+
+<!--- Insert answer here -->
+
+#### What is your Linux O.S. and which version?
+
+<!--- Insert answer here, e.g. Kali Linux 2019.1, Ubuntu 18.04 -->
+
+#### Which is the chipset of your wireless card?
+
+<!--- Insert answer here if apply -->
+
+#### Describe the issue and the steps to reproduce it
+
+<!--- Insert description here. Screenshots or any clarifying info are welcome too -->
diff --git a/.github/ISSUE_TEMPLATE/bug_report.md b/.github/ISSUE_TEMPLATE/bug_report.md
new file mode 100644
index 0000000..628ab78
--- /dev/null
+++ b/.github/ISSUE_TEMPLATE/bug_report.md
@@ -0,0 +1,32 @@
+---
+name: Bug report
+about: Create a report to help us improve
+title: ''
+labels: ''
+assignees: ''
+
+---
+
+<!--- Please, consider to contact us on Discord or IRC before opening an issue. More info and Discord invitation link here: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Contact -->
+<!--- Did you read the FAQ & Troubleshooting wiki section before asking? Maybe the answer is there: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/FAQ%20&%20Troubleshooting -->
+<!--- Answer the questions to provide maximum of info -->
+<!--- Filling this issue template is mandatory. Otherwise the issue can be directly closed -->
+<!--- Write in English only -->
+<!--- If additional info is required and requested by airgeddon's staff, you have 7 days to respond, otherwise the issue will be closed -->
+<!--- Read the Issue Creation Policy on Contributing section before creating the issue -->
+
+#### What is your airgeddon version?
+
+<!--- Insert answer here -->
+
+#### What is your Linux O.S. and which version?
+
+<!--- Insert answer here, e.g. Kali Linux 2019.1, Ubuntu 18.04 -->
+
+#### Which is the chipset of your wireless card?
+
+<!--- Insert answer here if apply -->
+
+#### Describe the issue and the steps to reproduce it
+
+<!--- Insert description here. Screenshots or any clarifying info are welcome too -->
diff --git a/.github/ISSUE_TEMPLATE/feature-request---compatibility-enhancement.md b/.github/ISSUE_TEMPLATE/feature-request---compatibility-enhancement.md
new file mode 100644
index 0000000..049f00c
--- /dev/null
+++ b/.github/ISSUE_TEMPLATE/feature-request---compatibility-enhancement.md
@@ -0,0 +1,24 @@
+---
+name: Feature request / compatibility enhancement
+about: Suggest an idea for this project
+title: ''
+labels: ''
+assignees: ''
+
+---
+
+<!--- Please, consider to contact us on Discord or IRC before opening an issue. More info and Discord invitation link here: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Contact -->
+<!--- Did you read the FAQ & Troubleshooting wiki section before doing this? Maybe the answer is there: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/FAQ%20&%20Troubleshooting -->
+<!--- Answer the questions to provide maximum of info -->
+<!--- Filling this issue template is mandatory. Otherwise the issue can be directly closed -->
+<!--- Write in English only -->
+<!--- If additional info is required and requested by airgeddon's staff, you have 7 days to respond, otherwise the issue will be closed -->
+<!--- Read the Issue Creation Policy on Contributing section before creating the issue -->
+
+#### Describe the feature or compatibility enhancement and involved versions if apply
+
+<!--- Insert answer here -->
+
+#### What are the benefits of adding this?
+
+<!--- Insert answer here -->
diff --git a/.github/ISSUE_TEMPLATE/general-question.md b/.github/ISSUE_TEMPLATE/general-question.md
new file mode 100644
index 0000000..7de3a93
--- /dev/null
+++ b/.github/ISSUE_TEMPLATE/general-question.md
@@ -0,0 +1,24 @@
+---
+name: General question
+about: Ask some general question
+title: ''
+labels: ''
+assignees: ''
+
+---
+
+<!--- Please, consider to contact us on Discord or IRC before opening an issue. More info and Discord invitation link here: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Contact -->
+<!--- Did you read the FAQ & Troubleshooting wiki section before asking? Maybe the answer is there: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/FAQ%20&%20Troubleshooting -->
+<!--- Answer the questions to provide maximum of info -->
+<!--- Filling this issue template is mandatory. Otherwise the issue can be directly closed -->
+<!--- Write in English only -->
+<!--- If additional info is required and requested by airgeddon's staff, you have 7 days to respond, otherwise the issue will be closed -->
+<!--- Read the Issue Creation Policy on Contributing section before creating the issue -->
+
+#### Is your question related to any concrete technology?
+
+<!--- Insert answer here, e.g. Linux, Docker, Wireless -->
+
+#### Describe your question as detailed as possible
+
+<!--- Insert answer here -->
diff --git a/.github/PULL_REQUEST_TEMPLATE.md b/.github/PULL_REQUEST_TEMPLATE.md
new file mode 100644
index 0000000..99f19a5
--- /dev/null
+++ b/.github/PULL_REQUEST_TEMPLATE.md
@@ -0,0 +1,10 @@
+<!--- Please, before sending a pull request read the Git Workflow Policy on Contributing section of the project -->
+<!--- If you have doubts about how to proceed, consider to contact us on Discord or IRC before doing the PR. More info and Discord invitation link here: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Contact -->
+<!--- Pull requests to master are not allowed -->
+<!--- Write in English only -->
+<!--- If your pull request is about a plugin, don't do it! airgeddon is not storing plugins. Read this about what to do: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Plugins%20Hall%20of%20Fame -->
+<!--- If the pull request is not matching the policy, it will be closed -->
+
+#### Describe the purpose of the pull request
+
+<!--- Insert answer here -->
diff --git a/.gitignore b/.gitignore
new file mode 100644
index 0000000..ed756a2
--- /dev/null
+++ b/.gitignore
@@ -0,0 +1,9 @@
+.DS_Store*
+._*
+.Spotlight-V100
+.Trashes
+ehthumbs.db
+Thumbs.db
+desktop.ini
+.dropbox*
+.idea
\ No newline at end of file
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 0de6cdb..dadaac2 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,3 +1,10 @@
+### 10.41
+ - Fixed error on PMKID hash validation
+ - Created an option to avoid Network Manager force killing on Evil Twin attacks
+ - Code improvements to allow new kind of arguments based plugins
+ - Dsniff Evil Twin captive portal DNS black hole replaced by dnsmasq
+ - Dockerfile rollback to Parrot (Parrot Security image as base) to avoid Arch Glibc + Dockerhub automated builds problem
+
 ### 10.40
  - Removed deprecated route command
  - Fixed error on WPS PINs found in database counter
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index d1bd7e8..7921809 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -84,6 +84,12 @@ Anything can be also discussed on public [IRC] or [Discord] channel. More info a
 
 ---
 
+## Discord Server Boosting
+
+Another way to contribute is to use your Nitro Boosts on our [Discord] server. After boosting, your name will appear as a _Server Booster_ contributor there. Check [Wiki Contact Section] for more info about how to connect to it.
+
+---
+
 ## Donate
 
 If you enjoyed the script, feel free to donate. Support the project through Paypal or sending a fraction any of these cryptocurrencies. Any amount, not matter how small (1, 2, 5 $/€) is welcome:
diff --git a/Dockerfile b/Dockerfile
index 2a7fe64..0085bff 100644
--- a/Dockerfile
+++ b/Dockerfile
@@ -1,7 +1,7 @@
 #airgeddon Dockerfile
 
 #Base image
-FROM archstrike/archstrike:latest
+FROM parrotsec/security:latest
 
 #Credits & Data
 LABEL \
@@ -13,45 +13,58 @@ LABEL \
 #Env vars
 ENV AIRGEDDON_URL="https://github.com/v1s1t0r1sh3r3/airgeddon.git"
 ENV HASHCAT2_URL="https://github.com/v1s1t0r1sh3r3/hashcat2.0.git"
-
-#Clear cache
-RUN yes | pacman -Scc --noconfirm
+ENV DEBIAN_FRONTEND="noninteractive"
 
 #Update system
-RUN pacman -Syyu --noconfirm
+RUN apt update
+
+#Set locales
+RUN \
+	apt -y install \
+	locales && \
+	locale-gen en_US.UTF-8 && \
+	sed -i -e 's/# en_US.UTF-8 UTF-8/en_US.UTF-8 UTF-8/' /etc/locale.gen && \
+	echo 'LANG="en_US.UTF-8"' > /etc/default/locale && \
+	dpkg-reconfigure --frontend=noninteractive locales && \
+	update-locale LANG=en_US.UTF-8
+
+#Env vars for locales
+ENV LANG="en_US.UTF-8"
+ENV LANGUAGE="en_US:en"
+ENV LC_ALL="en_US.UTF-8"
 
 #Install airgeddon essential tools
 RUN \
-	pacman -S --noconfirm \
+	apt -y install \
 	gawk \
 	iw \
 	aircrack-ng \
 	xterm \
 	iproute2 \
-	pciutils \
 	procps \
 	tmux
 
 #Install airgeddon internal tools
 RUN \
-	pacman -S --noconfirm \
+	apt -y install \
 	ethtool \
+	pciutils \
 	usbutils \
 	rfkill \
-	xorg-xdpyinfo \
+	x11-utils \
 	wget \
 	ccze \
-	xorg-xset
+	x11-xserver-utils
 
-#Install airgeddon update tools
+#Install update tools
 RUN \
-	pacman -S --noconfirm \
+	apt -y install \
 	curl \
 	git
 
 #Install airgeddon optional tools
 RUN \
-	pacman -S --noconfirm \
+	apt -y install \
 	crunch \
 	hashcat \
 	mdk3 \
@@ -60,9 +73,10 @@ RUN \
 	lighttpd \
 	iptables \
 	nftables \
-	ettercap \
-	dhcp \
-	dsniff \
+	ettercap-text-only \
+	bettercap \
+	isc-dhcp-server \
+	dnsmasq \
 	reaver \
 	bully \
 	pixiewps \
@@ -72,9 +86,8 @@ RUN \
 	openssl \
 	hcxtools \
 	hcxdumptool \
-	beef-git \
-	bettercap \
-	wireshark-cli
+	beef-xss \
+	tshark
 
 #Env var for display
 ENV DISPLAY=":0"
@@ -115,10 +128,13 @@ RUN \
 
 #Clean packages
 RUN \
-	yes | pacman -Sccc --noconfirm
+	apt clean && \
+	apt autoclean && \
+	apt autoremove -y
 
-#Clean and remove useless files
-RUN rm -rf /opt/airgeddon/imgs > /dev/null 2>&1 && \
+#Clean files
+RUN \
+	rm -rf /opt/airgeddon/imgs > /dev/null 2>&1 && \
 	rm -rf /opt/airgeddon/.github > /dev/null 2>&1 && \
 	rm -rf /opt/airgeddon/.editorconfig > /dev/null 2>&1 && \
 	rm -rf /opt/airgeddon/CONTRIBUTING.md > /dev/null 2>&1 && \
@@ -128,7 +144,8 @@ RUN rm -rf /opt/airgeddon/imgs > /dev/null 2>&1 && \
 	rm -rf /opt/airgeddon/binaries > /dev/null 2>&1 && \
 	rm -rf /opt/hashcat2.0 > /dev/null 2>&1 && \
 	rm -rf /opt/airgeddon/plugins/* > /dev/null 2>&1 && \
-	rm -rf /tmp/* > /dev/null 2>&1
+	rm -rf /tmp/* > /dev/null 2>&1 && \
+	rm -rf /var/lib/apt/lists/* > /dev/null 2>&1
 
 #Expose BeEF control panel port
 EXPOSE 3000
diff --git a/README.md b/README.md
index 24b86ec..36138b0 100644
--- a/README.md
+++ b/README.md
@@ -104,7 +104,7 @@ All the needed info about how to "install | use | enjoy" `airgeddon` is present
 [Hat Tip To]: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Hat%20Tip%20To
 [Inspiration]: https://github.com/v1s1t0r1sh3r3/airgeddon/wiki/Inspiration
 
-[Version-shield]: https://img.shields.io/badge/version-10.40-blue.svg?style=flat-square&colorA=273133&colorB=0093ee "Latest version"
+[Version-shield]: https://img.shields.io/badge/version-10.41-blue.svg?style=flat-square&colorA=273133&colorB=0093ee "Latest version"
 [Bash4.2-shield]: https://img.shields.io/badge/bash-4.2%2B-blue.svg?style=flat-square&colorA=273133&colorB=00db00 "Bash 4.2 or later"
 [License-shield]: https://img.shields.io/badge/license-GPL%20v3%2B-blue.svg?style=flat-square&colorA=273133&colorB=bd0000 "GPL v3+"
 [Docker-shield]: https://img.shields.io/docker/cloud/automated/v1s1t0r1sh3r3/airgeddon.svg?style=flat-square&colorA=273133&colorB=a9a9a9 "Docker rules!"
diff --git a/binaries/arch/airgeddon-git-10.41-1-any.pkg.tar.zst b/binaries/arch/airgeddon-git-10.41-1-any.pkg.tar.zst
new file mode 100644
index 0000000..5fc911d
Binary files /dev/null and b/binaries/arch/airgeddon-git-10.41-1-any.pkg.tar.zst differ
diff --git a/imgs/wiki/airgeddon_scrs1.png b/imgs/wiki/airgeddon_scrs1.png
index bd10fbb..3e43d6c 100644
Binary files a/imgs/wiki/airgeddon_scrs1.png and b/imgs/wiki/airgeddon_scrs1.png differ
diff --git a/imgs/wiki/airgeddon_scrs2.png b/imgs/wiki/airgeddon_scrs2.png
index 02362a4..adbb12d 100644
Binary files a/imgs/wiki/airgeddon_scrs2.png and b/imgs/wiki/airgeddon_scrs2.png differ
diff --git a/known_pins.db b/known_pins.db
index 45bac85..1312563 100644
--- a/known_pins.db
+++ b/known_pins.db
@@ -158,6 +158,7 @@ function set_pin_database() {
 	PINDB["1915C1"]="12345670"
 	PINDB["19DCED"]="45678965"
 	PINDB["1A0B40"]="17068161"
+	PINDB["1C3BF3"]="57522821"
 	PINDB["1C5F2B"]="69865879"
 	PINDB["1C740D"]="15843128"
 	PINDB["1C7EE5"]="76229909 37967635 92433960 22609298 60418579 60206732 27343043 65126141 43580293"
@@ -204,6 +205,7 @@ function set_pin_database() {
 	PINDB["3497F6"]="43218141"
 	PINDB["34BA9A"]="73235880"
 	PINDB["34CDBE"]="09656802"
+	PINDB["34E894"]="90855160 16552272"
 	PINDB["38229D"]="00779876 05537303 11967859 12749355 13409708 13849238 15116574 16538061 16811836 19986951 26427195 29942275 42497868 47148826 75284930 77828491 88202907 92537309"
 	PINDB["382C4A"]="90998980"
 	PINDB["3859F9"]="12475407"
@@ -227,6 +229,7 @@ function set_pin_database() {
 	PINDB["4CEDFB"]="85121003"
 	PINDB["4CFB45"]="63666922 60998125"
 	PINDB["4E26D4"]="51217563"
+	PINDB["500FF5"]="40881768"
 	PINDB["50465D"]="83010910 46540010 21101021 51504472 01101027 64214306 32120127"
 	PINDB["5067F0"]="20064525 66026402 12608065 12204786"
 	PINDB["5404A6"]="69923326 31028325 38014789"
@@ -247,6 +250,7 @@ function set_pin_database() {
 	PINDB["5C571A"]="46577450"
 	PINDB["5CD998"]="11554424 67554409 22630964"
 	PINDB["5CF96A"]="54353640"
+	PINDB["6032B1"]="45480928"
 	PINDB["60E327"]="36743025 56163926 20102043 23956544 34125335 83476532 86227728 09845237 59642114 31486811 26790732 08791320 24890687 09981331 48122726 38142178 47477445 28381204"
 	PINDB["623DFF"]="52029288"
 	PINDB["6253D4"]="21884603"
@@ -360,7 +364,7 @@ function set_pin_database() {
 	PINDB["A021B7"]="39149138 41252147 80324560 82581507 25815078 22813503 11352464 47624313 92442559 81121496 43454044 86559256 33440279 15880208 53134424 72218013 01874341 43135479 51920104 26515274 84361455 71202358 12345679 01318104"
 	PINDB["A0648F"]="51327330"
 	PINDB["A08E78"]="62306157"
-	PINDB["A0AB1B"]="44384494 85016279 20205515"
+	PINDB["A0AB1B"]="44384494 85016279 20205515 50975792 00327046 96421734 44915544 88008905"
 	PINDB["A0EC80"]="21970726 12345670"
 	PINDB["A0F3C1"]="03919934 32956092"
 	PINDB["A42B8C"]="21047015"
@@ -400,7 +404,7 @@ function set_pin_database() {
 	PINDB["BCF685"]="48782265 21464065 46264848"
 	PINDB["BEE3C4"]="75033941"
 	PINDB["BF06F4"]="20607470"
-	PINDB["C025E9"]="89346259 08645616"
+	PINDB["C025E9"]="89346259 08645616 48794558"
 	PINDB["C03F0E"]="25032918 45445402 49945386 41138571 13250003 09302525 14516894 83143632 63247435 94751345 50615056 30702073 53363480"
 	PINDB["C04A00"]="46182661 15706065 15268976 23682351 76746864 21249051 51644048 35747888"
 	PINDB["C054A5"]="12345678"
@@ -437,7 +441,7 @@ function set_pin_database() {
 	PINDB["D42122"]="00187558"
 	PINDB["D46E0E"]="43285632 64843018 76446825"
 	PINDB["D47BB0"]="14550911 98852413 70795660 20859978 13090586 67774128 14738340 11317890 53741134 22388414 72768198 11651659 83914829 36956074 11277576 16007666 29342273 18297492"
-	PINDB["D80D17"]="68325312"
+	PINDB["D80D17"]="68325312 12128532"
 	PINDB["D80F99"]="12345670"
 	PINDB["D850E6"]="42642107"
 	PINDB["D85D4C"]="73448907 13262204 11997870"
@@ -463,7 +467,7 @@ function set_pin_database() {
 	PINDB["E4C146"]="71537573 10009321 31348034 18794786 15738370 18546774 47415270 63742336 93782302 24248907 63668346 96453780 00000001"
 	PINDB["E839DF"]="14309489"
 	PINDB["E840F2"]="12345670 82585297 94380507"
-	PINDB["E894F6"]="45892066 36264957 25289794 36129836 16065420 69476150"
+	PINDB["E894F6"]="45892066 36264957 25289794 36129836 16065420 69476150 15522702"
 	PINDB["E8ABFA"]="11192091"
 	PINDB["E8CD2D"]="32151688"
 	PINDB["E8D11B"]="46240255 30859098 16615519 08935946 40033990 66543404"
diff --git a/language_strings.sh b/language_strings.sh
index 60c59ea..784961e 100644
--- a/language_strings.sh
+++ b/language_strings.sh
@@ -10,7 +10,7 @@ function set_language_strings_version() {
 
 	debug_print
 
-	language_strings_version="10.40-1"
+	language_strings_version="10.41-1"
 }
 
 #Set different language text strings
@@ -135,18 +135,18 @@ function initialize_language_strings() {
 	reboot_required["ARABIC"]="${red_color_slim} (المطلوب إعادة التشغيل) ${normal_color}"
 
 	declare -gA docker_image
-	docker_image["ENGLISH"]="ArchStrike Docker image based"
-	docker_image["SPANISH"]="Basado en imagen de Docker de ArchStrike"
-	docker_image["FRENCH"]="Fondé sur l'image de Docker d'ArchStrike"
-	docker_image["CATALAN"]="Basat en imatge de Docker de ArchStrike"
-	docker_image["PORTUGUESE"]="Baseado na imagem Docker do ArchStrike"
-	docker_image["RUSSIAN"]="Основано на образе ArchStrike Docker"
-	docker_image["GREEK"]="Με βάση to ArchStrike Docker image"
-	docker_image["ITALIAN"]="Basato sull'immagine di Docker di ArchStrike"
-	docker_image["POLISH"]="${pending_of_translation} Na podstawie obrazu ArchStrike Docker"
-	docker_image["GERMAN"]="Auf dem ArchStrike Docker-Image"
-	docker_image["TURKISH"]="ArchStrike Docker image tabanlı"
-	docker_image["ARABIC"]="Docker ArchStrike الصورة مبنية على"
+	docker_image["ENGLISH"]="Parrot Docker image based"
+	docker_image["SPANISH"]="Basado en imagen de Docker de Parrot"
+	docker_image["FRENCH"]="Fondé sur l'image de Docker d'Parrot"
+	docker_image["CATALAN"]="Basat en imatge de Docker de Parrot"
+	docker_image["PORTUGUESE"]="Baseado na imagem Docker do Parrot"
+	docker_image["RUSSIAN"]="Основано на образе Parrot Docker"
+	docker_image["GREEK"]="Με βάση to Parrot Docker image"
+	docker_image["ITALIAN"]="Basato sull'immagine di Docker di Parrot"
+	docker_image["POLISH"]="${pending_of_translation} Na podstawie obrazu Parrot Docker"
+	docker_image["GERMAN"]="Auf dem Parrot Docker-Image"
+	docker_image["TURKISH"]="Parrot Docker image tabanlı"
+	docker_image["ARABIC"]="Docker Parrot الصورة مبنية على"
 
 	declare -gA et_misc_texts
 	et_misc_texts["ENGLISH",0]="Evil Twin AP Info"
@@ -1042,18 +1042,18 @@ function initialize_language_strings() {
 	arr["TURKISH",5]="Görünüşe göre internet bağlantınız dengesiz. Yazılım depoya bağlanamadı. Güncelleme olmadan devam edilecek..."
 	arr["ARABIC",5]="...يبدو أن اتصالك بالإنترنت غير مستقر. البرنامج لا يمكنه الاتصال بالمستودع. سيستمر دون تحديث"
 
-	arr["ENGLISH",6]="Welcome to airgeddon script v\${airgeddon_version}"
-	arr["SPANISH",6]="Bienvenid@ a airgeddon script v\${airgeddon_version}"
-	arr["FRENCH",6]="Bienvenue au script airgeddon v\${airgeddon_version}"
-	arr["CATALAN",6]="Benvingut a airgeddon script v\${airgeddon_version}"
-	arr["PORTUGUESE",6]="Bem-vindo ao script airgeddon v\${airgeddon_version}"
-	arr["RUSSIAN",6]="Добро пожаловать в скрипт airgeddon v\${airgeddon_version}"
-	arr["GREEK",6]="Καλωσήρθατε στο airgeddon v\${airgeddon_version}"
-	arr["ITALIAN",6]="Benvenuti a airgeddon script v\${airgeddon_version}"
-	arr["POLISH",6]="Witaj w skrypcie airgeddon v\${airgeddon_version}"
-	arr["GERMAN",6]="Willkommen bei airgeddon Skript v\${airgeddon_version}"
-	arr["TURKISH",6]="airgeddon yazılımına hoşgeldiniz v\${airgeddon_version}"
-	arr["ARABIC",6]="v\${airgeddon_version} airgeddon مرحبا بكم في"
+	arr["ENGLISH",6]="Welcome to airgeddon script \${normal_color}v\${airgeddon_version}"
+	arr["SPANISH",6]="Bienvenid@ a airgeddon script \${normal_color}v\${airgeddon_version}"
+	arr["FRENCH",6]="Bienvenue au script airgeddon \${normal_color}v\${airgeddon_version}"
+	arr["CATALAN",6]="Benvingut a airgeddon script \${normal_color}v\${airgeddon_version}"
+	arr["PORTUGUESE",6]="Bem-vindo ao script airgeddon \${normal_color}v\${airgeddon_version}"
+	arr["RUSSIAN",6]="Добро пожаловать в скрипт airgeddon \${normal_color}v\${airgeddon_version}"
+	arr["GREEK",6]="Καλωσήρθατε στο airgeddon \${normal_color}v\${airgeddon_version}"
+	arr["ITALIAN",6]="Benvenuti a airgeddon script \${normal_color}v\${airgeddon_version}"
+	arr["POLISH",6]="Witaj w skrypcie airgeddon \${normal_color}v\${airgeddon_version}"
+	arr["GERMAN",6]="Willkommen bei airgeddon Skript \${normal_color}v\${airgeddon_version}"
+	arr["TURKISH",6]="airgeddon yazılımına hoşgeldiniz \${normal_color}v\${airgeddon_version}"
+	arr["ARABIC",6]="\${normal_color}v\${airgeddon_version}\${blue_color} airgeddon مرحبا بكم في"
 
 	arr["ENGLISH",7]="This script is only for educational purposes. Be good boyz&girlz!"
 	arr["SPANISH",7]="Este script se ha hecho sólo con fines educativos. Sed buen@s chic@s!"
@@ -1107,18 +1107,18 @@ function initialize_language_strings() {
 	arr["TURKISH",10]="Bu arayüz \${current_iface_on_messages} zaten izleme modunda"
 	arr["ARABIC",10]="Monitor mode  في وضع  \${current_iface_on_messages} هذه الواجهة"
 
-	arr["ENGLISH",11]="Exiting airgeddon script v\${airgeddon_version} - See you soon! :)"
-	arr["SPANISH",11]="Saliendo de airgeddon script v\${airgeddon_version} - Nos vemos pronto! :)"
-	arr["FRENCH",11]="Fermeture du script airgeddon v\${airgeddon_version} - A bientôt! :)"
-	arr["CATALAN",11]="Sortint de airgeddon script v\${airgeddon_version} - Ens veiem aviat! :)"
-	arr["PORTUGUESE",11]="Saindo do script airgeddon v\${airgeddon_version} - Até breve! :)"
-	arr["RUSSIAN",11]="Выход из скрипта airgeddon v\${airgeddon_version} - До встречи! :)"
-	arr["GREEK",11]="Κλείσιμο του airgeddon v\${airgeddon_version} - Αντίο! :)"
-	arr["ITALIAN",11]="Abbandonando airgeddon script v\${airgeddon_version} - A presto! :)"
-	arr["POLISH",11]="Wyjście z skryptu airgeddon v\${airgeddon_version} - Do zobaczenia wkrótce! :)"
-	arr["GERMAN",11]="Sie verlassen airgeddon Skript v\${airgeddon_version} - Bis bald! :)"
-	arr["TURKISH",11]="airgeddon yazılımından çıkış yapılıyor v\${airgeddon_version} - Tekrar görüşürüz! :)"
-	arr["ARABIC",11]="اراك قريبا! :) -  v\${airgeddon_version}  الخروج من البرنامج"
+	arr["ENGLISH",11]="Exiting airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} - See you soon! :)"
+	arr["SPANISH",11]="Saliendo de airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} - Nos vemos pronto! :)"
+	arr["FRENCH",11]="Fermeture du script airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} - A bientôt! :)"
+	arr["CATALAN",11]="Sortint de airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} - Ens veiem aviat! :)"
+	arr["PORTUGUESE",11]="Saindo do script airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} - Até breve! :)"
+	arr["RUSSIAN",11]="Выход из скрипта airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} - До встречи! :)"
+	arr["GREEK",11]="Κλείσιμο του airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} - Αντίο! :)"
+	arr["ITALIAN",11]="Abbandonando airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} - A presto! :)"
+	arr["POLISH",11]="Wyjście z skryptu airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} - Do zobaczenia wkrótce! :)"
+	arr["GERMAN",11]="Sie verlassen airgeddon Skript \${normal_color}v\${airgeddon_version}\${blue_color} - Bis bald! :)"
+	arr["TURKISH",11]="airgeddon yazılımından çıkış yapılıyor \${normal_color}v\${airgeddon_version}\${blue_color} - Tekrar görüşürüz! :)"
+	arr["ARABIC",11]="اراك قريبا! :) - \${normal_color}v\${airgeddon_version}\${blue_color} الخروج من البرنامج"
 
 	arr["ENGLISH",12]="\${blue_color}Interruption detected. \${green_color}Do you really want to exit? \${normal_color}\${visual_choice}"
 	arr["SPANISH",12]="\${blue_color}Detectada interrupción. \${green_color}¿Quieres realmente salir del script? \${normal_color}\${visual_choice}"
@@ -1913,18 +1913,18 @@ function initialize_language_strings() {
 	arr["TURKISH",72]="Gerçersiz hedef ağ seçildi"
 	arr["ARABIC",72]="تم اختيار شبكة مستهدفة غير صالحة"
 
-	arr["ENGLISH",73]="airgeddon script v\${airgeddon_version} developed by:"
-	arr["SPANISH",73]="airgeddon script v\${airgeddon_version} programado por:"
-	arr["FRENCH",73]="Le script airgeddon v\${airgeddon_version} a été programmé par:"
-	arr["CATALAN",73]="airgeddon script v\${airgeddon_version} desenvolupat per:"
-	arr["PORTUGUESE",73]="Script airgeddon v\${airgeddon_version} desenvolvido por:"
-	arr["RUSSIAN",73]="скрипт airgeddon v\${airgeddon_version} создал:"
-	arr["GREEK",73]="Το airgeddon script v\${airgeddon_version} προγραμματίστηκε από:"
-	arr["ITALIAN",73]="airgeddon script v\${airgeddon_version} sviluppato da:"
-	arr["POLISH",73]="Skrypt airgeddon v\${airgeddon_version} napisany przez:"
-	arr["GERMAN",73]="airgeddon Skript v\${airgeddon_version} entwickelt von:"
-	arr["TURKISH",73]="airgeddon yazılımı v\${airgeddon_version} geliştiricisi:"
-	arr["ARABIC",73]=":بواسطة v\${airgeddon_version} تمت برمجة"
+	arr["ENGLISH",73]="airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} developed by:"
+	arr["SPANISH",73]="airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} programado por:"
+	arr["FRENCH",73]="Le script airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} a été programmé par:"
+	arr["CATALAN",73]="airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} desenvolupat per:"
+	arr["PORTUGUESE",73]="Script airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} desenvolvido por:"
+	arr["RUSSIAN",73]="скрипт airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} создал:"
+	arr["GREEK",73]="Το airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} προγραμματίστηκε από:"
+	arr["ITALIAN",73]="airgeddon script \${normal_color}v\${airgeddon_version}\${blue_color} sviluppato da:"
+	arr["POLISH",73]="Skrypt airgeddon \${normal_color}v\${airgeddon_version}\${blue_color} napisany przez:"
+	arr["GERMAN",73]="airgeddon Skript \${normal_color}v\${airgeddon_version}\${blue_color} entwickelt von:"
+	arr["TURKISH",73]="airgeddon yazılımı \${normal_color}v\${airgeddon_version}\${blue_color} geliştiricisi:"
+	arr["ARABIC",73]=":بواسطة \${normal_color}v\${airgeddon_version}\${blue_color} تمت برمجة"
 
 	arr["ENGLISH",74]="This script is under GPLv3 (or later) License"
 	arr["SPANISH",74]="Este script está bajo Licencia GPLv3 (o posterior)"
@@ -6775,18 +6775,18 @@ function initialize_language_strings() {
 	arr["TURKISH",446]="0.  Ayarlar menüsüne geri dön"
 	arr["ARABIC",446]="0.  العودة إلى قائمة الخيارات"
 
-	arr["ENGLISH",447]="13. Set permanently airgeddon's language to the current one"
-	arr["SPANISH",447]="13. Cambiar permanentemente el idioma de airgeddon al actual"
-	arr["FRENCH",447]="13. Etablir comme langue permanente d'airgeddon celle utilisée actuellement"
-	arr["CATALAN",447]="13. Canviar permanentment l'idioma de airgeddon a l'actual"
-	arr["PORTUGUESE",447]="13. Alterar permanentemente o idioma do airgeddon para o atual"
-	arr["RUSSIAN",447]="13. Сделать текущий язык airgeddon постоянным"
-	arr["GREEK",447]="13. Θέστε μόνιμα την τρέχουσα γλώσσα του airgeddon ως προεπιλεγμένη"
-	arr["ITALIAN",447]="13. Modificare in modo permanente la lingua di airgeddon a quella attuale"
-	arr["POLISH",447]="13. Trwale ustaw język airgeddon na aktualny"
-	arr["GERMAN",447]="13. Ändern Sie dauerhaft die Sprache von airgeddon zur aktuellen Sprache"
-	arr["TURKISH",447]="13. Sürekli olarak airgeddon'un dilini geçerli olana ayarla"
-	arr["ARABIC",447]="13. بشكل دائم على اللغة الحالية airgeddon اضبط لغة"
+	arr["ENGLISH",447]="14. Set permanently airgeddon's language to the current one"
+	arr["SPANISH",447]="14. Cambiar permanentemente el idioma de airgeddon al actual"
+	arr["FRENCH",447]="14. Etablir comme langue permanente d'airgeddon celle utilisée actuellement"
+	arr["CATALAN",447]="14. Canviar permanentment l'idioma de airgeddon a l'actual"
+	arr["PORTUGUESE",447]="14. Alterar permanentemente o idioma do airgeddon para o atual"
+	arr["RUSSIAN",447]="14. Сделать текущий язык airgeddon постоянным"
+	arr["GREEK",447]="14. Θέστε μόνιμα την τρέχουσα γλώσσα του airgeddon ως προεπιλεγμένη"
+	arr["ITALIAN",447]="14. Modificare in modo permanente la lingua di airgeddon a quella attuale"
+	arr["POLISH",447]="14. Trwale ustaw język airgeddon na aktualny"
+	arr["GERMAN",447]="14. Ändern Sie dauerhaft die Sprache von airgeddon zur aktuellen Sprache"
+	arr["TURKISH",447]="14. Sürekli olarak airgeddon'un dilini geçerli olana ayarla"
+	arr["ARABIC",447]="14. بشكل دائم على اللغة الحالية airgeddon اضبط لغة"
 
 	arr["ENGLISH",448]="If you installed airgeddon from a repository, you should not enable automatic updates. airgeddon will be updated when there is a new version in the repository"
 	arr["SPANISH",448]="Si instalaste airgeddon desde un repositorio, no deberías activar la actualización automática. airgeddon se actualizará cuando haya una nueva versión en el repositorio"
@@ -9900,12 +9900,116 @@ function initialize_language_strings() {
 	arr["CATALAN",687]="12. Àrab"
 	arr["PORTUGUESE",687]="12. Árabe"
 	arr["RUSSIAN",687]="12. Арабский"
-	arr["GREEK",687]="12. Αραβικός"
+	arr["GREEK",687]="12. Αραβικά"
 	arr["ITALIAN",687]="12. Araba"
 	arr["POLISH",687]="12. Arabski"
 	arr["GERMAN",687]="12. Arabisch"
 	arr["TURKISH",687]="12. Arapça"
 	arr["ARABIC",687]="12. عربى"
+
+	arr["ENGLISH",688]="13. Disable Network Manager force stop permanently"
+	arr["SPANISH",688]="13. Deshabilitar forzado de parada de Network Manager permanentemente"
+	arr["FRENCH",688]="13. Désactiver en permanence l'arrêt forcé de Network Manager"
+	arr["CATALAN",688]="13. Deshabilitar forçat de parada de Network Manager permanentment"
+	arr["PORTUGUESE",688]="13. Desativar permanentemente o desligamento automático do Network Manager"
+	arr["RUSSIAN",688]="\${pending_of_translation} 13. Отключить принудительное завершение работы Network Manager навсегда"
+	arr["GREEK",688]="13. Απενεργοποιήστε μόνιμα τον αναγκαστικό τερματισμό του Διαχειριστή Δικτύου"
+	arr["ITALIAN",688]="13. Disattivare l'arresto forzato del Network Manager in modo permanente"
+	arr["POLISH",688]="\${pending_of_translation} 13. Trwale wyłącz wymuszone zamknięcie Menedżera sieci"
+	arr["GERMAN",688]="13. Deaktivieren Sie das erzwungene Herunterfahren von Network Manager dauerhaft"
+	arr["TURKISH",688]="13. Ağ Yöneticisi'nin kapanmaya zorlamasını kalıcı olarak devre dışı bırakın"
+	arr["ARABIC",688]="13. تعطيل الإغلاق القسري لمدير الشبكة بشكل دائم"
+
+	arr["ENGLISH",689]="13. Enable Network Manager force stop permanently"
+	arr["SPANISH",689]="13. Habilitar forzado de parada de Network Manager permanentemente"
+	arr["FRENCH",689]="13. Activer forcer l'arrêt de Network Manager en permanence"
+	arr["CATALAN",689]="13. Habilitar forçat de parada de Network Manager permanentment"
+	arr["PORTUGUESE",689]="13. Ativar permanentemente o desligamento automático do Network Manager"
+	arr["RUSSIAN",689]="\${pending_of_translation} 13. Разрешить принудительное завершение работы Network Manager навсегда"
+	arr["GREEK",689]="13. Ενεργοποίηστε μόνιμα τον αναγκαστικό τερματισμό του Διαχειριστή Δικτύου"
+	arr["ITALIAN",689]="13. Attivare l'arresto forzato del Network Manager in modo permanente"
+	arr["POLISH",689]="\${pending_of_translation} 13. Włącz wymuszone zamknięcie Menedżera sieci na stałe"
+	arr["GERMAN",689]="13. Aktivieren Sie das dauerhafte Herunterfahren von Network Manager"
+	arr["TURKISH",689]="13. Ağ Yöneticisi'nin kalıcı olarak kapanmaya zorlanmasını etkinleştir"
+	arr["ARABIC",689]="13. تفعيل الإغلاق القسري لمدير الشبكة بشكل دائم"
+
+	arr["ENGLISH",690]="Network Manager force stop: \${pink_color}Enabled\${normal_color}"
+	arr["SPANISH",690]="Forzado de parada de Network Manager: \${pink_color}Activado\${normal_color}"
+	arr["FRENCH",690]="Arrêt forcé de Network Manager: \${pink_color}Activée\${normal_color}"
+	arr["CATALAN",690]="Forçat de parada de Network Manager: \${pink_color}Activat\${normal_color}"
+	arr["PORTUGUESE",690]="Desligamento automático do Network Manager: \${pink_color}Ativo\${normal_color}"
+	arr["RUSSIAN",690]="\${pending_of_translation} Принудительная остановка сетевого менеджера: \${pink_color}Включено\${normal_color}"
+	arr["GREEK",690]="Αναγκαστικός τερματισμός του Διαχειριστή Δικτύου: \${pink_color}Ενεργοποιημένος\${normal_color}"
+	arr["ITALIAN",690]="Arresto forzato del Network Manager: \${pink_color}Attivato\${normal_color}"
+	arr["POLISH",690]="\${pending_of_translation} Menedżer sieci wymusił zatrzymanie: \${pink_color}Włączony\${normal_color}"
+	arr["GERMAN",690]="Network Manager erzwungener Stopp: \${pink_color}Aktiviert\${normal_color}"
+	arr["TURKISH",690]="Ağ Yöneticisi zorunlu durdurma: \${pink_color}Aktif\${normal_color}"
+	arr["ARABIC",690]="\${pink_color}مفعل\${blue_color} :توقف إجباري لمديرالشبكة\${normal_color}"
+
+	arr["ENGLISH",691]="Network Manager force stop: \${pink_color}Disabled\${normal_color}"
+	arr["SPANISH",691]="Forzado de parada de Network Manager: \${pink_color}Desactivado\${normal_color}"
+	arr["FRENCH",691]="Arrêt forcé de Network Manager: \${pink_color}Désactivée\${normal_color}"
+	arr["CATALAN",691]="Forçat de parada de Network Manager: \${pink_color}Desactivat\${normal_color}"
+	arr["PORTUGUESE",691]="Desligamento automático do Network Manager: \${pink_color}Desativo\${normal_color}"
+	arr["RUSSIAN",691]="\${pending_of_translation} Принудительная остановка сетевого менеджера: \${pink_color}Отключено\${normal_color}"
+	arr["GREEK",691]="Αναγκαστικός τερματισμός του Διαχειριστή Δικτύου: \${pink_color}Απενεργοποιημένος\${normal_color}"
+	arr["ITALIAN",691]="Arresto forzato del Network Manager: \${pink_color}Disattivato\${normal_color}"
+	arr["POLISH",691]="\${pending_of_translation} Menedżer sieci wymusił zatrzymanie: \${pink_color}Dezaktywowane\${normal_color}"
+	arr["GERMAN",691]="Network Manager erzwungener Stopp: \${pink_color}Deaktiviert\${normal_color}"
+	arr["TURKISH",691]="Ağ Yöneticisi zorunlu durdurma: \${pink_color}Devredışı\${normal_color}"
+	arr["ARABIC",691]="\${pink_color}معطل\${blue_color} :توقف إجباري لمديرالشبكة\${normal_color}"
+
+	arr["ENGLISH",692]="\${blue_color}Network Manager force stop will be disabled. \${green_color}Do you want to continue? \${normal_color}\${visual_choice}"
+	arr["SPANISH",692]="\${blue_color}Se va a deshabilitar el forzado de parada de Network Manager. \${green_color}¿Deseas continuar? \${normal_color}\${visual_choice}"
+	arr["FRENCH",692]="\${blue_color}L'arrêt forcé de Network Manager sera désactivé. \${green_color}Voulez-vous continuer? \${normal_color}\${visual_choice}"
+	arr["CATALAN",692]="\${blue_color}Es va a desactivar el forçat de parada de Network Manager. \${green_color}¿Vols continuar? \${normal_color}\${visual_choice}"
+	arr["PORTUGUESE",692]="\${blue_color}O Network Manager não será desligado automáticamente. \${green_color}Você deseja continuar? \${normal_color}\${visual_choice}"
+	arr["RUSSIAN",692]="\${pending_of_translation} \${blue_color}Принудительное завершение работы Network Manager будет отключено. \${green_color}Вы хотите продолжить? \${normal_color}\${visual_choice}"
+	arr["GREEK",692]="\${blue_color}Ο αναγκαστικός τερματισμός του Διαχειριστή Δικτύου θα απενεργοποιηθεί. \${green_color}Θέλετε να συνεχίσετε; \${normal_color}\${visual_choice}"
+	arr["ITALIAN",692]="\${blue_color}L'arresto forzato del Network Manager verrà disattivato. \${green_color}Vuoi continuare? \${normal_color}\${visual_choice}"
+	arr["POLISH",692]="\${pending_of_translation} \${blue_color}Wymuszone zamknięcie programu Network Manager zostanie wyłączone. \${green_color}Czy chcesz kontynuować? \${normal_color}\${visual_choice}"
+	arr["GERMAN",692]="\${blue_color}Das erzwungene Herunterfahren von Network Manager wird deaktiviert. \${green_color}Möchten Sie fortfahren? \${normal_color}\${visual_choice}"
+	arr["TURKISH",692]="\${blue_color}Ağ Yöneticisi zorunlu kapatma devre dışı bırakılacak. \${green_color}Devam etmek istiyor musunuz? \${normal_color}\${visual_choice}"
+	arr["ARABIC",692]="\${normal_color}\${visual_choice}\${green_color} هل تريد المتابعة؟\${blue_color} .سيتم تعطيل إيقاف التشغيل الإجباري لمديرالشبكة\${normal_color}"
+
+	arr["ENGLISH",693]="\${blue_color}Network Manager force stop will be enabled. \${green_color}Do you want to continue? \${normal_color}\${visual_choice}"
+	arr["SPANISH",693]="\${blue_color}Se va a habilitar el forzado de parada de Network Manager. \${green_color}¿Deseas continuar? \${normal_color}\${visual_choice}"
+	arr["FRENCH",693]="\${blue_color}L'arrêt forcé de Network Manager sera activé. \${green_color}Voulez-vous continuer? \${normal_color}\${visual_choice}"
+	arr["CATALAN",693]="\${blue_color}Es va a habilitar el forçat de parada de Network Manager. \${green_color}¿Vols continuar? \${normal_color}\${visual_choice}"
+	arr["PORTUGUESE",693]="\${blue_color}O Network Manager será desligado automáticamente. \${green_color}Você deseja continuar? \${normal_color}\${visual_choice}"
+	arr["RUSSIAN",693]="\${pending_of_translation} \${blue_color}Будет включен принудительный останов Network Manager. \${green_color}Вы хотите продолжить? \${normal_color}\${visual_choice}"
+	arr["GREEK",693]="\${blue_color}Ο αναγκαστικός τερματισμός του Διαχειριστή Δικτύου θα ενεργοποιηθεί. \${green_color}Θέλετε να συνεχίσετε; \${normal_color}\${visual_choice}"
+	arr["ITALIAN",693]="\${blue_color}L'arresto forzato del Network Manager verrà attivato \${green_color}Vuoi continuare? \${normal_color}\${visual_choice}"
+	arr["POLISH",693]="\${pending_of_translation} \${blue_color}Network Manager Force Stop zostanie włączony. \${green_color}Czy chcesz kontynuować? \${normal_color}\${visual_choice}"
+	arr["GERMAN",693]="\${blue_color}Network Manager erzwungener Stopp wird aktiviert. \${green_color}Möchten Sie fortfahren? \${normal_color}\${visual_choice}"
+	arr["TURKISH",693]="\${blue_color}Ağ Yöneticisi Zorla Durdurma etkinleştirilecek. \${green_color}Devam etmek istiyor musunuz? \${normal_color}\${visual_choice}"
+	arr["ARABIC",693]="\${normal_color}\${visual_choice}\${green_color} هل تريد المتابعة؟\${blue_color} .سيتم تفعيل إيقاف التشغيل الإجباري لمديرالشبكة\${normal_color}"
+
+	arr["ENGLISH",694]="Network Manager force stop has been disabled"
+	arr["SPANISH",694]="Se ha desactivado el forzado de parada de Network Manager"
+	arr["FRENCH",694]="L'arrêt forcé de Network Manager a été désactivé"
+	arr["CATALAN",694]="S'ha desactivat el forçat de parada de Network Manager"
+	arr["PORTUGUESE",694]="O deligamento automático do Network Manager foi desativo"
+	arr["RUSSIAN",694]="\${pending_of_translation} Принудительная остановка Network Manager отключена"
+	arr["GREEK",694]="Ο αναγκαστικός τερματισμός του Διαχειριστή Δικτύου έχει απενεργοποιηθεί"
+	arr["ITALIAN",694]="L'arresto forzato del Network Manager è stato disattivato"
+	arr["POLISH",694]="\${pending_of_translation} Wymuszone zatrzymanie programu Network Manager zostało wyłączone"
+	arr["GERMAN",694]="Der Network Manager erzwungener Stopp wurde deaktiviert"
+	arr["TURKISH",694]="Ağ Yöneticisi zorla durdurma devre dışı bırakıldı"
+	arr["ARABIC",694]="تم تعطيل التشغيل الإجباري لمديرالشبكة"
+
+	arr["ENGLISH",695]="Network Manager force stop has been enabled"
+	arr["SPANISH",695]="Se ha activado el forzado de parada de Network Manager"
+	arr["FRENCH",695]="L'arrêt forcé de Network Manager a été activé"
+	arr["CATALAN",695]="S'ha activat el forçat de parada de Network Manager"
+	arr["PORTUGUESE",695]="O deligamento automático do Network Manager foi ativo"
+	arr["RUSSIAN",695]="\${pending_of_translation} Принудительная остановка Network Manager активирована"
+	arr["GREEK",695]="Ο αναγκαστικός τερματισμός του Διαχειριστή Δικτύου έχει ενεργοποιηθεί"
+	arr["ITALIAN",695]="L'arresto forzato del Network Manager è stato attivato"
+	arr["POLISH",695]="\${pending_of_translation} Aktywowano wymuszone zatrzymanie programu Network Manager"
+	arr["GERMAN",695]="Network Manager erzwungener Stopp wurde aktiviert"
+	arr["TURKISH",695]="Ağ Yöneticisi zorla durdurma etkinleştirildi"
+	arr["ARABIC",695]="تم تفعيل التشغيل الإجباري لمديرالشبكة"
 }
 
 #Expand escaped variables in language strings with their actual values
@@ -9914,7 +10018,6 @@ function replace_string_vars() {
 	debug_print
 
 	local message
-	local replace
 	message=${arr[${1},${2}]}
 	parsed_message=$(echo "${message}" | sed -E 's/\"/\\\"/g')
 	eval "echo -e \"${parsed_message}\""
diff --git a/pindb_checksum.txt b/pindb_checksum.txt
index 112b363..56bd746 100644
--- a/pindb_checksum.txt
+++ b/pindb_checksum.txt
@@ -1 +1 @@
-873418ed6b1b412d5be10461efd4c579
+27c2fc2a468ac26404aa8080b4d258d6
diff --git a/plugins/missing_dependencies.sh b/plugins/missing_dependencies.sh
index c0f5844..4cac7c6 100644
--- a/plugins/missing_dependencies.sh
+++ b/plugins/missing_dependencies.sh
@@ -49,7 +49,7 @@ function commands_to_packages() {
 			commands_to_packages_correspondence["ettercap"]="ettercap-text-only"
 			commands_to_packages_correspondence["etterlog"]="ettercap-text-only"
 			commands_to_packages_correspondence["lighttpd"]="lighttpd"
-			commands_to_packages_correspondence["dnsspoof"]="dsniff"
+			commands_to_packages_correspondence["dnsmasq"]="dnsmasq"
 			commands_to_packages_correspondence["wash"]="reaver"
 			commands_to_packages_correspondence["reaver"]="reaver"
 			commands_to_packages_correspondence["bully"]="bully"
@@ -96,7 +96,7 @@ function commands_to_packages() {
 			commands_to_packages_correspondence["ettercap"]="ettercap"
 			commands_to_packages_correspondence["etterlog"]="ettercap"
 			commands_to_packages_correspondence["lighttpd"]="lighttpd"
-			commands_to_packages_correspondence["dnsspoof"]="dsniff"
+			commands_to_packages_correspondence["dnsmasq"]="dnsmasq"
 			commands_to_packages_correspondence["wash"]="reaver"
 			commands_to_packages_correspondence["reaver"]="reaver"
 			commands_to_packages_correspondence["bully"]="bully"
diff --git a/airgeddon.sh b/airgeddon.sh
index ccbaf9a..8c718fb 100755
--- a/airgeddon.sh
+++ b/airgeddon.sh
@@ -2,7 +2,7 @@
 #Title........: airgeddon.sh
 #Description..: This is a multi-use bash script for Linux systems to audit wireless networks.
 #Author.......: v1s1t0r
-#Version......: 10.40
+#Version......: 10.41
 #Usage........: bash airgeddon.sh
 #Bash Version.: 4.2 or later
 
@@ -57,7 +57,7 @@ optional_tools_names=(
 						"ettercap"
 						"etterlog"
 						"lighttpd"
-						"dnsspoof"
+						"dnsmasq"
 						"wash"
 						"reaver"
 						"bully"
@@ -107,7 +107,7 @@ declare -A possible_package_names=(
 									[${optional_tools_names[8]}]="ettercap / ettercap-text-only / ettercap-graphical" #ettercap
 									[${optional_tools_names[9]}]="ettercap / ettercap-text-only / ettercap-graphical" #etterlog
 									[${optional_tools_names[10]}]="lighttpd" #lighttpd
-									[${optional_tools_names[11]}]="dsniff" #dnsspoof
+									[${optional_tools_names[11]}]="dnsmasq" #dnsmasq
 									[${optional_tools_names[12]}]="reaver" #wash
 									[${optional_tools_names[13]}]="reaver" #reaver
 									[${optional_tools_names[14]}]="bully" #bully
@@ -131,8 +131,8 @@ declare -A possible_alias_names=(
 								)
 
 #General vars
-airgeddon_version="10.40"
-language_strings_expected_version="10.40-1"
+airgeddon_version="10.41"
+language_strings_expected_version="10.41-1"
 standardhandshake_filename="handshake-01.cap"
 standardpmkid_filename="pmkid_hash.txt"
 standardpmkidcap_filename="pmkid.cap"
@@ -194,7 +194,7 @@ wep_key_handler="ag.wep_key_handler.sh"
 wep_processes_file="wep_processes"
 
 #Docker vars
-docker_based_distro="Arch"
+docker_based_distro="Parrot"
 docker_io_dir="/io/"
 
 #WPS vars
@@ -249,7 +249,7 @@ loopback_ip="127.0.0.1"
 loopback_ipv6="::1/128"
 routing_tmp_file="ag.iptables_nftables"
 dhcpd_file="ag.dhcpd.conf"
-hosts_file="ag.hosts"
+dnsmasq_file="ag.dnsmasq.conf"
 internet_dns1="8.8.8.8"
 internet_dns2="8.8.4.4"
 internet_dns3="139.130.4.5"
@@ -1725,6 +1725,11 @@ function option_menu() {
 	else
 		language_strings "${language}" 652
 	fi
+	if "${AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING:-true}"; then
+		language_strings "${language}" 688
+	else
+		language_strings "${language}" 689
+	fi
 	language_strings "${language}" 447
 	print_hint ${current_menu}
 
@@ -2012,6 +2017,33 @@ function option_menu() {
 			fi
 		;;
 		13)
+			if "${AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING:-true}"; then
+				ask_yesno 692 "yes"
+				if [ "${yesno}" = "y" ]; then
+					if option_toggle "AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING"; then
+						echo
+						language_strings "${language}" 694 "blue"
+					else
+						echo
+						language_strings "${language}" 417 "red"
+					fi
+					language_strings "${language}" 115 "read"
+				fi
+			else
+				ask_yesno 693 "yes"
+				if [ "${yesno}" = "y" ]; then
+					if option_toggle "AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING"; then
+						echo
+						language_strings "${language}" 695 "blue"
+					else
+						echo
+						language_strings "${language}" 417 "red"
+					fi
+					language_strings "${language}" 115 "read"
+				fi
+			fi
+		;;
+		14)
 			ask_yesno 478 "yes"
 			if [ "${yesno}" = "y" ]; then
 				get_current_permanent_language
@@ -4925,6 +4957,12 @@ function print_options() {
 		language_strings "${language}" 595 "blue"
 	fi
 
+	if "${AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING:-true}"; then
+		language_strings "${language}" 690 "blue"
+	else
+		language_strings "${language}" 691 "blue"
+	fi
+
 	reboot_required_text=""
 	if [ "${AIRGEDDON_WINDOWS_HANDLING}" = "xterm" ]; then
 		if grep -q "AIRGEDDON_WINDOWS_HANDLING=tmux" "${rc_path}" 2> /dev/null; then
@@ -5402,7 +5440,7 @@ function clean_env_vars() {
 
 	debug_print
 
-	unset AIRGEDDON_AUTO_UPDATE AIRGEDDON_SKIP_INTRO AIRGEDDON_BASIC_COLORS AIRGEDDON_EXTENDED_COLORS AIRGEDDON_AUTO_CHANGE_LANGUAGE AIRGEDDON_SILENT_CHECKS AIRGEDDON_PRINT_HINTS AIRGEDDON_5GHZ_ENABLED AIRGEDDON_FORCE_IPTABLES AIRGEDDON_MDK_VERSION AIRGEDDON_PLUGINS_ENABLED AIRGEDDON_DEVELOPMENT_MODE AIRGEDDON_DEBUG_MODE AIRGEDDON_WINDOWS_HANDLING
+	unset AIRGEDDON_AUTO_UPDATE AIRGEDDON_SKIP_INTRO AIRGEDDON_BASIC_COLORS AIRGEDDON_EXTENDED_COLORS AIRGEDDON_AUTO_CHANGE_LANGUAGE AIRGEDDON_SILENT_CHECKS AIRGEDDON_PRINT_HINTS AIRGEDDON_5GHZ_ENABLED AIRGEDDON_FORCE_IPTABLES AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING AIRGEDDON_MDK_VERSION AIRGEDDON_PLUGINS_ENABLED AIRGEDDON_DEVELOPMENT_MODE AIRGEDDON_DEBUG_MODE AIRGEDDON_WINDOWS_HANDLING
 }
 
 #Clean temporary files
@@ -5424,7 +5462,7 @@ function clean_tmpfiles() {
 	rm -rf "${tmpdir}${hostapd_wpe_file}" > /dev/null 2>&1
 	rm -rf "${tmpdir}${hostapd_wpe_log}" > /dev/null 2>&1
 	rm -rf "${tmpdir}${dhcpd_file}" > /dev/null 2>&1
-	rm -rf "${tmpdir}${hosts_file}" >/dev/null 2>&1
+	rm -rf "${tmpdir}${dnsmasq_file}" >/dev/null 2>&1
 	rm -rf "${tmpdir}${control_et_file}" > /dev/null 2>&1
 	rm -rf "${tmpdir}${control_enterprise_file}" > /dev/null 2>&1
 	rm -rf "${tmpdir}parsed_file" > /dev/null 2>&1
@@ -7240,7 +7278,7 @@ function validate_pmkid_hashcat_file() {
 	readarray -t HASHCAT_LINES_TO_VALIDATE < <(cat "${1}" 2> /dev/null)
 
 	for item in "${HASHCAT_LINES_TO_VALIDATE[@]}"; do
-		if [[ ! "${item}" =~ ^WPA\*[0-9]{2}\*[0-9a-fA-F]{32}\*([0-9a-fA-F]{12}\*){2}[0-9a-fA-F]{26,28}\*{3}$ ]]; then
+		if [[ ! "${item}" =~ ^WPA\*[0-9]{2}\*[0-9a-fA-F]{32}\*([0-9a-fA-F]{12}\*){2}[0-9a-fA-F]{26,32}\*+.*$ ]]; then
 			language_strings "${language}" 676 "red"
 			language_strings "${language}" 115 "read"
 			return 1
@@ -9003,9 +9041,14 @@ function launch_fake_ap() {
 		kill "$(ps -C hostapd --no-headers -o pid | tr -d ' ')" &> /dev/null
 	fi
 
-	if [ "${check_kill_needed}" -eq 1 ]; then
+	if "${AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING:-true}"; then
 		${airmon} check kill > /dev/null 2>&1
 		nm_processes_killed=1
+	else
+		if [ "${check_kill_needed}" -eq 1 ]; then
+			${airmon} check kill > /dev/null 2>&1
+			nm_processes_killed=1
+		fi
 	fi
 
 	if [ ${mac_spoofing_desired} -eq 1 ]; then
@@ -10186,9 +10229,13 @@ function set_et_control_script() {
 				} >> "${et_captive_portal_logpath}"
 
 				sleep 2
+	EOF
+
+	cat >&7 <<-'EOF'
 				kill "$(ps -C hostapd --no-headers -o pid | tr -d ' ')" &> /dev/null
 				kill "$(ps -C dhcpd --no-headers -o pid | tr -d ' ')" &> /dev/null
 				kill "$(ps -C aireplay-ng --no-headers -o pid | tr -d ' ')" &> /dev/null
+				kill "$(ps -C dnsmasq --no-headers -o pid | tr -d ' ')" &> /dev/null
 				kill "$(ps -C lighttpd --no-headers -o pid | tr -d ' ')" &> /dev/null
 				kill_et_windows
 	EOF
@@ -10328,7 +10375,7 @@ function set_et_control_script() {
 	sleep 1
 }
 
 #Launch dnsspoof dns black hole for captive portal Evil Twin attack
 function launch_dns_blackhole() {
 
 	debug_print
@@ -10336,20 +10383,25 @@ function launch_dns_blackhole() {
 	recalculate_windows_sizes
 
 	tmpfiles_toclean=1
-	rm -rf "${tmpdir}${hosts_file}" > /dev/null 2>&1
+	rm -rf "${tmpdir}${dnsmasq_file}" > /dev/null 2>&1
 
 	{
-	echo -e "${et_ip_router}\t*.*"
-	echo -e "172.217.5.238\tgoogle.com"
-	echo -e "172.217.13.78\tclients3.google.com"
-	echo -e "172.217.13.78\tclients4.google.com"
-	} >> "${tmpdir}${hosts_file}"
-
-	manage_output "-hold -bg \"#000000\" -fg \"#0000FF\" -geometry ${g4_middleright_window} -T \"DNS\"" "${optional_tools_names[11]} -i ${interface} -f \"${tmpdir}${hosts_file}\"" "DNS"
+	echo -e "interface=${interface}"
+	echo -e "address=/#/${et_ip_router}"
+	echo -e "address=/google.com/172.217.5.238"
+	echo -e "address=/gstatic.com/172.217.5.238"
+	echo -e "no-dhcp-interface=${interface}"
+	echo -e "log-queries"
+	echo -e "no-daemon"
+	echo -e "no-resolv"
+	echo -e "no-hosts"
+	} >> "${tmpdir}${dnsmasq_file}"
+
+	manage_output "-hold -bg \"#000000\" -fg \"#0000FF\" -geometry ${g4_middleright_window} -T \"DNS\"" "${optional_tools_names[11]} -C \"${tmpdir}${dnsmasq_file}\"" "DNS"
 	if [ "${AIRGEDDON_WINDOWS_HANDLING}" = "xterm" ]; then
 		et_processes+=($!)
 	else
-		get_tmux_process_id "${optional_tools_names[11]} -i ${interface} -f \"${tmpdir}${hosts_file}\""
+		get_tmux_process_id "${optional_tools_names[11]} -C \"${tmpdir}${dnsmasq_file}\""
 		et_processes+=("${global_process_pid}")
 		global_process_pid=""
 	fi
@@ -11212,6 +11264,7 @@ function kill_et_windows() {
 	else
 		kill "${et_process_control_window}" &> /dev/null
 		kill "$(ps -C hostapd --no-headers -o pid | tr -d ' ')" &> /dev/null
+		kill "$(ps -C dnsmasq --no-headers -o pid | tr -d ' ')" &> /dev/null
 	fi
 
 	if [ "${AIRGEDDON_WINDOWS_HANDLING}" = "tmux" ]; then
@@ -14689,19 +14742,20 @@ function env_vars_initialization() {
 									"AIRGEDDON_PRINT_HINTS" #6
 									"AIRGEDDON_5GHZ_ENABLED" #7
 									"AIRGEDDON_FORCE_IPTABLES" #8
-									"AIRGEDDON_MDK_VERSION" #9
-									"AIRGEDDON_PLUGINS_ENABLED" #10
-									"AIRGEDDON_DEVELOPMENT_MODE" #11
-									"AIRGEDDON_DEBUG_MODE" #12
-									"AIRGEDDON_WINDOWS_HANDLING" #13
+									"AIRGEDDON_FORCE_NETWORK_MANAGER_KILLING" #9
+									"AIRGEDDON_MDK_VERSION" #10
+									"AIRGEDDON_PLUGINS_ENABLED" #11
+									"AIRGEDDON_DEVELOPMENT_MODE" #12
+									"AIRGEDDON_DEBUG_MODE" #13
+									"AIRGEDDON_WINDOWS_HANDLING" #14
 									)
 
 	declare -gA nonboolean_options_env_vars
-	nonboolean_options_env_vars["${ordered_options_env_vars[9]},default_value"]="mdk4" #mdk_version
-	nonboolean_options_env_vars["${ordered_options_env_vars[13]},default_value"]="xterm" #windows_handling
+	nonboolean_options_env_vars["${ordered_options_env_vars[10]},default_value"]="mdk4" #mdk_version
+	nonboolean_options_env_vars["${ordered_options_env_vars[14]},default_value"]="xterm" #windows_handling
 
-	nonboolean_options_env_vars["${ordered_options_env_vars[9]},rcfile_text"]="#Available values: mdk3, mdk4 - Define which mdk version is going to be used - Default value ${nonboolean_options_env_vars[${ordered_options_env_vars[9]},'default_value']}"
-	nonboolean_options_env_vars["${ordered_options_env_vars[13]},rcfile_text"]="#Available values: xterm, tmux - Define the needed tool to be used for windows handling - Default value ${nonboolean_options_env_vars[${ordered_options_env_vars[13]},'default_value']}"
+	nonboolean_options_env_vars["${ordered_options_env_vars[10]},rcfile_text"]="#Available values: mdk3, mdk4 - Define which mdk version is going to be used - Default value ${nonboolean_options_env_vars[${ordered_options_env_vars[10]},'default_value']}"
+	nonboolean_options_env_vars["${ordered_options_env_vars[14]},rcfile_text"]="#Available values: xterm, tmux - Define the needed tool to be used for windows handling - Default value ${nonboolean_options_env_vars[${ordered_options_env_vars[14]},'default_value']}"
 
 	declare -gA boolean_options_env_vars
 	boolean_options_env_vars["${ordered_options_env_vars[0]},default_value"]="true" #auto_update
@@ -14713,9 +14767,10 @@ function env_vars_initialization() {
 	boolean_options_env_vars["${ordered_options_env_vars[6]},default_value"]="true" #print_hints
 	boolean_options_env_vars["${ordered_options_env_vars[7]},default_value"]="true" #5ghz_enabled
 	boolean_options_env_vars["${ordered_options_env_vars[8]},default_value"]="false" #force_iptables
-	boolean_options_env_vars["${ordered_options_env_vars[10]},default_value"]="true" #plugins_enabled
-	boolean_options_env_vars["${ordered_options_env_vars[11]},default_value"]="false" #development_mode
-	boolean_options_env_vars["${ordered_options_env_vars[12]},default_value"]="false" #debug_mode
+	boolean_options_env_vars["${ordered_options_env_vars[9]},default_value"]="true" #force_network_manager_killing
+	boolean_options_env_vars["${ordered_options_env_vars[11]},default_value"]="true" #plugins_enabled
+	boolean_options_env_vars["${ordered_options_env_vars[12]},default_value"]="false" #development_mode
+	boolean_options_env_vars["${ordered_options_env_vars[13]},default_value"]="false" #debug_mode
 
 	boolean_options_env_vars["${ordered_options_env_vars[0]},rcfile_text"]="#Enabled true / Disabled false - Auto update feature (it has no effect on development mode) - Default value ${boolean_options_env_vars[${ordered_options_env_vars[0]},'default_value']}"
 	boolean_options_env_vars["${ordered_options_env_vars[1]},rcfile_text"]="#Enabled true / Disabled false - Skip intro (it has no effect on development mode) - Default value ${boolean_options_env_vars[${ordered_options_env_vars[1]},'default_value']}"
@@ -14726,9 +14781,10 @@ function env_vars_initialization() {
 	boolean_options_env_vars["${ordered_options_env_vars[6]},rcfile_text"]="#Enabled true / Disabled false - Print help hints on menus - Default value ${boolean_options_env_vars[${ordered_options_env_vars[6]},'default_value']}"
 	boolean_options_env_vars["${ordered_options_env_vars[7]},rcfile_text"]="#Enabled true / Disabled false - Enable 5Ghz support (it has no effect if your cards are not 5Ghz compatible cards) - Default value ${boolean_options_env_vars[${ordered_options_env_vars[7]},'default_value']}"
 	boolean_options_env_vars["${ordered_options_env_vars[8]},rcfile_text"]="#Enabled true / Disabled false - Force to use iptables instead of nftables (it has no effect if nftables are not present) - Default value ${boolean_options_env_vars[${ordered_options_env_vars[8]},'default_value']}"
-	boolean_options_env_vars["${ordered_options_env_vars[10]},rcfile_text"]="#Enabled true / Disabled false - Enable plugins system - Default value ${boolean_options_env_vars[${ordered_options_env_vars[10]},'default_value']}"
-	boolean_options_env_vars["${ordered_options_env_vars[11]},rcfile_text"]="#Enabled true / Disabled false - Development mode for faster development skipping intro and all initial checks - Default value ${boolean_options_env_vars[${ordered_options_env_vars[11]},'default_value']}"
-	boolean_options_env_vars["${ordered_options_env_vars[12]},rcfile_text"]="#Enabled true / Disabled false - Debug mode for development printing debug information - Default value ${boolean_options_env_vars[${ordered_options_env_vars[12]},'default_value']}"
+	boolean_options_env_vars["${ordered_options_env_vars[9]},rcfile_text"]="#Enabled true / Disabled false - Force to kill Network Manager before launching Evil Twin attacks - Default value ${boolean_options_env_vars[${ordered_options_env_vars[9]},'default_value']}"
+	boolean_options_env_vars["${ordered_options_env_vars[11]},rcfile_text"]="#Enabled true / Disabled false - Enable plugins system - Default value ${boolean_options_env_vars[${ordered_options_env_vars[11]},'default_value']}"
+	boolean_options_env_vars["${ordered_options_env_vars[12]},rcfile_text"]="#Enabled true / Disabled false - Development mode for faster development skipping intro and all initial checks - Default value ${boolean_options_env_vars[${ordered_options_env_vars[12]},'default_value']}"
+	boolean_options_env_vars["${ordered_options_env_vars[13]},rcfile_text"]="#Enabled true / Disabled false - Debug mode for development printing debug information - Default value ${boolean_options_env_vars[${ordered_options_env_vars[13]},'default_value']}"
 
 	readarray -t ENV_VARS_ELEMENTS < <(printf %s\\n "${!nonboolean_options_env_vars[@]} ${!boolean_options_env_vars[@]}" | cut -d, -f1 | sort -u)
 	readarray -t ENV_BOOLEAN_VARS_ELEMENTS < <(printf %s\\n "${!boolean_options_env_vars[@]}" | cut -d, -f1 | sort -u)
@@ -15010,8 +15066,8 @@ function check_inside_tmux() {
 
 	local parent_pid
 	local parent_window
-	parent_pid=$(ps -o ppid= ${PPID} | tr -d ' ')
-	parent_window="$(ps --no-headers -p "${parent_pid}" -o comm=)"
+	parent_pid=$(ps -o ppid= ${PPID} 2> /dev/null | tr -d ' ')
+	parent_window="$(ps --no-headers -p "${parent_pid}" -o comm= 2> /dev/null)"
 	if [[ "${parent_window}" =~ tmux ]]; then
 		return 0
 	fi
@@ -15169,7 +15225,7 @@ function parse_plugins() {
 					plugin_short_name="${plugin_short_name%.sh*}"
 
 					#shellcheck source=./plugins/missing_dependencies.sh
-					source "${file}"
+					source "${file}" "$@"
 					if [ "${plugin_enabled}" -eq 1 ]; then
 						validate_plugin_requirements
 						plugin_validation_result=$?
@@ -15783,7 +15839,7 @@ function main() {
 	dependencies_modifications
 
 	if "${AIRGEDDON_PLUGINS_ENABLED:-true}"; then
-		parse_plugins
+		parse_plugins "$@"
 		apply_plugin_functions_rewriting
 	fi
 
@@ -15885,4 +15941,4 @@ for f in SIGINT SIGHUP INT SIGTSTP; do
 	eval "${trap_cmd}"
 done
 
-main
+main "$@"
@@ -10328,7 +10375,7 @@ function set_et_control_script() {
 }
 
-#Launch dnsspoof dns black hole for captive portal Evil Twin attack
+#Launch dnsmasq dns black hole for captive portal Evil Twin attack
 function launch_dns_blackhole() {
 